@@ -16,7 +16,7 @@
 #include <QMouseEvent>
 #include <QScrollBar>
 
-#include <klocale.h>
+#include <klocalizedstring.h>
 #include <math.h>
 
 mapWidget::mapWidget(QWidget *parent) : QGraphicsView(parent)
@@ -229,4 +229,4 @@ void mapWidget::updateActions()
 	emit setZoomActionChecked( p_mode == Zooming || p_mode == WantZoom );
 }
 
-#include "mapwidget.moc"
+
